@@ -85,14 +85,14 @@ bool KCharSelectData::openDataFile()
     if (!dataFile.isEmpty()) {
         return true;
     } else {
-        QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kcharselect/kcharselect-data"));
+        const QString kcharselectDataPath = QStringLiteral("kf6/kcharselect/kcharselect-data");
+        QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, kcharselectDataPath);
         if (fileName.isEmpty()) {
             fileName = QStringLiteral(TOP_SRCDIR "/src/kcharselect-data"); // for autotests before installation
         }
         QFile file(fileName);
         if (!file.open(QIODevice::ReadOnly)) {
-            qWarning() << "Couldn't find kf5/kcharselect/kcharselect-data in the install prefix (under GenericDataLocation) nor in the builtin path"
-                       << TOP_SRCDIR;
+            qWarning() << "Couldn't find " << kcharselectDataPath << " in the install prefix (under GenericDataLocation) nor in the builtin path" << TOP_SRCDIR;
             return false;
         }
         dataFile = file.readAll();
@@ -108,7 +108,7 @@ bool KCharSelectData::openDataFile()
         if (blocks <= 167) { // maximum possible number of blocks in BMP
             // no remapping
             remapType = -1;
-        } else if (blocks >= 174 && blocks <= 179) {
+        } else if (blocks >= 174 && blocks <= 180) {
             // remapping introduced in 5.25
             remapType = 0;
         } else {
@@ -210,10 +210,10 @@ QString KCharSelectData::formatCode(uint code, int length, const QString &prefix
     return s;
 }
 
-QVector<uint> KCharSelectData::blockContents(int block)
+QList<uint> KCharSelectData::blockContents(int block)
 {
     if (!openDataFile()) {
-        return QVector<uint>();
+        return QList<uint>();
     }
 
     const uchar *data = reinterpret_cast<const uchar *>(dataFile.constData());
@@ -222,7 +222,7 @@ QVector<uint> KCharSelectData::blockContents(int block)
 
     int max = ((offsetEnd - offsetBegin) / 4) - 1;
 
-    QVector<uint> res;
+    QList<uint> res;
 
     if (block > max) {
         return res;
@@ -235,15 +235,16 @@ QVector<uint> KCharSelectData::blockContents(int block)
         res.append(mapDataBaseToCodePoint(unicodeBegin));
         unicodeBegin++;
     }
-    res.append(mapDataBaseToCodePoint(unicodeBegin)); // Be carefull when unicodeEnd==0xffff
+    res.append(mapDataBaseToCodePoint(unicodeBegin)); // Be careful when unicodeEnd==0xffff
 
     return res;
 }
 
-QVector<int> KCharSelectData::sectionContents(int section)
+QList<int> KCharSelectData::sectionContents(int section)
 {
+    section -= 1;
     if (!openDataFile()) {
-        return QVector<int>();
+        return QList<int>();
     }
 
     const uchar *data = reinterpret_cast<const uchar *>(dataFile.constData());
@@ -252,7 +253,7 @@ QVector<int> KCharSelectData::sectionContents(int section)
 
     int max = ((offsetEnd - offsetBegin) / 4) - 1;
 
-    QVector<int> res;
+    QList<int> res;
 
     if (section > max) {
         return res;
@@ -260,7 +261,7 @@ QVector<int> KCharSelectData::sectionContents(int section)
 
     for (int i = 0; i <= max; i++) {
         const quint16 currSection = qFromLittleEndian<quint16>(data + offsetBegin + i * 4);
-        if (currSection == section) {
+        if (currSection == section || section < 0) {
             res.append(qFromLittleEndian<quint16>(data + offsetBegin + i * 4 + 2));
         }
     }
@@ -281,6 +282,7 @@ QStringList KCharSelectData::sectionList()
     const char *data = dataFile.constData();
     QStringList list;
     quint32 i = stringBegin;
+    list.append(QCoreApplication::translate("KCharSelectData", "All", "KCharSelect section name"));
     while (i < stringEnd) {
         list.append(QCoreApplication::translate("KCharSelectData", data + i, "KCharSelect section name"));
         i += qstrlen(data + i) + 1;
@@ -312,7 +314,9 @@ QString KCharSelectData::name(uint c)
     } else if (c >= 0xAC00 && c <= 0xD7AF) {
         /* compute hangul syllable name as per UAX #15 */
         int SIndex = c - SBase;
-        int LIndex, VIndex, TIndex;
+        int LIndex;
+        int VIndex;
+        int TIndex;
 
         if (SIndex < 0 || SIndex >= SCount) {
             return QString();
@@ -409,7 +413,7 @@ int KCharSelectData::sectionIndex(int block)
 
     for (int i = 0; i <= max; i++) {
         if (qFromLittleEndian<quint16>(data + offsetBegin + i * 4 + 2) == block) {
-            return qFromLittleEndian<quint16>(data + offsetBegin + i * 4);
+            return qFromLittleEndian<quint16>(data + offsetBegin + i * 4) + 1;
         }
     }
 
@@ -440,10 +444,15 @@ QString KCharSelectData::blockName(int index)
 
 QString KCharSelectData::sectionName(int index)
 {
+    if (index == 0) {
+        return QCoreApplication::translate("KCharSelectData", "All", "KCharselect unicode section name");
+    }
     if (!openDataFile()) {
         return QString();
     }
 
+    index -= 1;
+
     const uchar *udata = reinterpret_cast<const uchar *>(dataFile.constData());
     const quint32 stringBegin = qFromLittleEndian<quint32>(udata + 24);
     const quint32 stringEnd = qFromLittleEndian<quint32>(udata + 28);
@@ -511,21 +520,21 @@ QStringList KCharSelectData::notes(uint c)
     return notes;
 }
 
-QVector<uint> KCharSelectData::seeAlso(uint c)
+QList<uint> KCharSelectData::seeAlso(uint c)
 {
     if (!openDataFile()) {
-        return QVector<uint>();
+        return QList<uint>();
     }
     const int detailIndex = getDetailIndex(c);
     if (detailIndex == 0) {
-        return QVector<uint>();
+        return QList<uint>();
     }
 
     const uchar *udata = reinterpret_cast<const uchar *>(dataFile.constData());
     const quint8 count = *(quint8 *)(udata + detailIndex + 26);
     quint32 offset = qFromLittleEndian<quint32>(udata + detailIndex + 22);
 
-    QVector<uint> seeAlso;
+    QList<uint> seeAlso;
     seeAlso.reserve(count);
 
     for (int i = 0; i < count; i++) {
@@ -588,18 +597,18 @@ QStringList KCharSelectData::approximateEquivalents(uint c)
     return approxEquivalents;
 }
 
-QVector<uint> KCharSelectData::decomposition(uint c)
+QList<uint> KCharSelectData::decomposition(uint c)
 {
     // for now, only decompose Hangul Syllable into Hangul Jamo
     uint SIndex = c - SBase;
     if (SIndex >= SCount) {
-        return QVector<uint>();
+        return QList<uint>();
     }
 
     uint L = LBase + SIndex / NCount; // Choseong
     uint V = VBase + (SIndex % NCount) / TCount; // Jungseong
     uint T = TBase + SIndex % TCount; // Jongsung
-    QVector<uint> jamoList;
+    QList<uint> jamoList;
     jamoList.append(L);
     jamoList.append(V);
     if (T != TBase) {
@@ -845,11 +854,11 @@ QString KCharSelectData::categoryText(QChar::Category category)
     }
 }
 
-QVector<uint> KCharSelectData::find(const QString &needle)
+QList<uint> KCharSelectData::find(const QString &needle)
 {
     QSet<uint> result;
 
-    QVector<uint> returnRes;
+    QList<uint> returnRes;
     QString simplified = needle.length() > 1 ? needle.simplified() : needle;
     QStringList searchStrings;
 
@@ -873,10 +882,12 @@ QVector<uint> KCharSelectData::find(const QString &needle)
     }
 
     if (simplified.length() <= 2) {
-        QVector<uint> ucs4 = simplified.toUcs4();
+        QList<uint> ucs4 = simplified.toUcs4();
         if (ucs4.size() == 1) {
             // search for hex representation of the character
             searchStrings = QStringList(formatCode(ucs4.at(0)));
+        } else {
+            searchStrings = splitString(simplified);
         }
     } else {
         searchStrings = splitString(simplified);
@@ -887,7 +898,7 @@ QVector<uint> KCharSelectData::find(const QString &needle)
     }
 
     static const QRegularExpression hexExp(QStringLiteral("^(?:|u\\+|U\\+|0x|0X)([A-Fa-f0-9]{4,5})$"));
-    for (const QString &s : qAsConst(searchStrings)) {
+    for (const QString &s : std::as_const(searchStrings)) {
         const QRegularExpressionMatch match = hexExp.match(s);
         if (match.hasMatch()) {
             const QString cap = match.captured(1);
@@ -906,7 +917,7 @@ QVector<uint> KCharSelectData::find(const QString &needle)
     }
 
     bool firstSubString = true;
-    for (const QString &s : qAsConst(searchStrings)) {
+    for (const QString &s : std::as_const(searchStrings)) {
         QSet<uint> partResult = getMatchingChars(s.toLower());
         if (firstSubString) {
             result = partResult;
@@ -918,13 +929,13 @@ QVector<uint> KCharSelectData::find(const QString &needle)
 
     // remove results found by matching the code point to prevent duplicate results
     // while letting these characters stay at the beginning
-    for (uint c : qAsConst(returnRes)) {
+    for (uint c : std::as_const(returnRes)) {
         result.remove(c);
     }
 
-    QVector<uint> sortedResult;
+    QList<uint> sortedResult;
     sortedResult.reserve(result.count());
-    for (auto c : qAsConst(result)) {
+    for (auto c : std::as_const(result)) {
         sortedResult.append(c);
     }
     std::sort(sortedResult.begin(), sortedResult.end());
