@@ -627,3 +627,14 @@ void KMultiTabBar::fontChange(const QFont & /* oldFont */)
 {
     updateGeometry();
 }
+
+void KMultiTabBar::paintEvent(class QPaintEvent *)
+{
+    // By default plain QWidget don't call the QStyle and are transparent
+    // using drawPrimitive(QStyle::PE_Widget) allow QStyle implementation
+    // to theme this class.
+    QPainter painter(this);
+    QStyleOption opt;
+    opt.initFrom(this);
+    style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
+}
