@@ -17,10 +17,12 @@
 #define KTOGGLEACTION_H
 
 #include <QAction>
+#include <memory>
 
 #include <kwidgetsaddons_export.h>
 
 class KGuiItem;
+class KToggleActionPrivate;
 
 /**
  *  @class KToggleAction ktoggleaction.h KToggleAction
@@ -72,7 +74,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~KToggleAction();
+    ~KToggleAction() override;
 
     /**
      * Defines the text (and icon, tooltip, whatsthis) that should be displayed
@@ -89,9 +91,14 @@ public:
 protected Q_SLOTS:
     virtual void slotToggled(bool checked);
 
+protected:
+    KWIDGETSADDONS_NO_EXPORT KToggleAction(KToggleActionPrivate &dd, QObject *parent);
+
+protected:
+    std::unique_ptr<class KToggleActionPrivate> const d_ptr;
+
 private:
-    class Private;
-    Private *const d;
+    Q_DECLARE_PRIVATE(KToggleAction)
 };
 
 #endif
